# Structure Analyzer Featurizer (SAF)

![PR](https://img.shields.io/badge/PR-Welcome-29ab47ff)
![PyPI](https://img.shields.io/pypi/v/structure-analyzer-featurizer)
![PythonVersion](https://img.shields.io/pypi/pyversions/structure-analyzer-featurizer)

Structure Analyzer/Featurizer (SAF) is a Python package to generate geometric features of interatomic distances, atomic environment information, and coordination numbers from a folder containing .cif files.

Features:

- Generate hundreds of numerical structural features for **binary**, **ternary**, and **quaternary** `.cif` files.
- No coding required - command-line interactive [app](https://github.com/bobleesj/structure-analyzer-featurizer-app) provided.
- Process hundreds to tens of thousands of .cif files.

## Publications

If you use `SAF` in your scientific publication, please cite the software packages:

> _Digital Discovery_, https://doi.org/10.1039/D4DD00332B

as well as the `cifkit` which is the engine of `SAF` for coordination environment analysis:

> _Journal of Open Source Software_, https://doi.org/10.21105/joss.07205

## Getting started

To learn more, please read the official documentation at https://bobleesj.github.io/structure-analyzer-featurizer.

## Acknowledgements

`SAF` is built and maintained with [scikit-package](https://scikit-package.github.io/scikit-package/).
